This package is a part of Dustico research process regarding issue - [Don't run setup.py egg_info on pip download --no-deps #1884](https://github.com/pypa/pip/issues/1884) 

Disclaimer - once being downloaded - attempts to ping back our servers.

For questions, please contact us via email at [research@dusti.co](mailto:research@dusti.co)